=============================
Tendril Config Infrastructure
=============================

.. image:: https://img.shields.io/travis/chintal/tendril-config.svg
        :target: https://travis-ci.org/chintal/tendril-config

.. image:: https://img.shields.io/pypi/v/tendril-config.svg
        :target: https://pypi.python.org/pypi/tendril-config

* License: AGPLv3
* Documentation: http://tendril-config.readthedocs.org


Tendril Config Infrastructure

